@@ -1,23 +1,23 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2007 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2010 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
 
-#ifndef DB_BASE_H
-#define DB_BASE_H
+#ifndef __DB_BASE_H
+#define __DB_BASE_H
 
 #include "db.h"
 #include "base.h"
 #include "load_obj.h"
-#include <qlistview.h>
-#include <qpixmap.h>
-#include <qstringlist.h>
-#include <qpixmap.h>
-#include <qabstractitemmodel.h>
+#include <QtGui/QListView>
+#include <QtGui/QPixmap>
+#include <QtGui/QContextMenuEvent>
+#include <QtCore/QStringList>
+#include <QtCore/QAbstractItemModel>
 #include "pki_base.h"
-#include "widgets/XcaTreeView.h"
+//#include "widgets/XcaTreeView.h"
 
 #define FOR_ALL_pki(pki, pki_type) \
 	for(pki_type *pki=(pki_type*)rootItem->iterate(); pki; pki=(pki_type*)pki->iterate())
@@ -32,17 +32,16 @@ class db_base: public QAbstractItemModel
 	Q_OBJECT
 
 	protected:
-		QString dbName, delete_txt;
+		QString dbName;
 		QModelIndex currentIdx;
-		void _writePKI(pki_base *pki, bool overwrite );
+		void _writePKI(pki_base *pki, bool overwrite);
 		void _removePKI(pki_base *pki );
 		void removeItem(QString k);
-		enum pki_type pkitype[4];
-		QList<QVariant> headertext;
+		QList<enum pki_type> pkitype;
 		MainWindow *mainwin;
-		XcaTreeView *view;
 		QString class_name;
-
+		dbheaderList allHeaders;
+		int colResizing;
 	public:
 		pki_base *rootItem;
 		db_base(QString db, MainWindow *mw);
@@ -80,19 +79,45 @@ class db_base: public QAbstractItemModel
 		void storeSelectedItems(XcaTreeView *view);
 		void load_default(load_base &load);
 		void insertChild(pki_base *parent, pki_base *child);
+		void createSuccess(pki_base *pki);
+		void showHeaderMenu(QContextMenuEvent *e, int sect);
+		bool columnHidden(int col) const;
+		bool isNumericCol(int col) const;
+		void saveHeaderState();
+		void contextMenu(QContextMenuEvent *e,
+			QMenu *parent = NULL, int sect = -1);
+		void initHeaderView(QHeaderView *hv);
+		void setVisualIndex(int i, int visualIndex);
+		bool fixedHeaderSize(int sect);
+		void colResizeStart()
+		{
+			colResizing++;
+		}
+		void colResizeEnd()
+		{
+			colResizing--;
+		}
 
 	public slots:
 		void deletePKI();
 		void delete_ask();
 		void edit();
+		void columnResetDefaults();
 		virtual void showItem();
 		virtual void store(){};
 		virtual void showPki(pki_base *) {};
 		virtual void showItem(const QModelIndex &index);
 		virtual void showItem(const QString keyname);
+		void sectionResized(int i, int, int newSize);
+		void sortIndicatorChanged(int logicalIndex, Qt::SortOrder order);
+		void pem2clipboard();
 
 	signals:
 		void connNewX509(NewX509 *dlg);
+		void resetHeader();
+		void updateHeader();
+		void columnsContentChanged();
+		void editItem(const QModelIndex &);
 };
 
 #endif
