@@ -1,6 +1,6 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2011 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2014 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
@@ -95,8 +95,7 @@ pki_base *db_crl::insert(pki_base *item)
 	pki_crl *crl = (pki_crl *)item;
 	pki_crl *oldcrl = (pki_crl *)getByReference(crl);
 	if (oldcrl) {
-		QMessageBox::information(mainwin, XCA_TITLE,
-			tr("The revokation list already exists in the database as:\n'%1'\nand so it was not imported").arg(oldcrl->getIntName()));
+		XCA_INFO(tr("The revokation list already exists in the database as:\n'%1'\nand so it was not imported").arg(oldcrl->getIntName()));
 		delete(crl);
 		return NULL;
 	}
@@ -133,7 +132,7 @@ void db_crl::store()
 	ExportDer *dlg = new ExportDer(mainwin, fn,
 			tr("CRL ( *.pem *.der *.crl )"));
 	dlg->image->setPixmap(*MainWindow::revImg);
-	dlg->label->setText(tr("Revokation list export"));
+	dlg->label->setText(tr("Revocation list export"));
 	int dlgret = dlg->exec();
 
 	if (!dlgret) {
