@@ -1,6 +1,6 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2010 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2014 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
@@ -45,8 +45,7 @@ db_temp::db_temp(QString DBfile, MainWindow *mw)
 			if (tmpl)
 				predefs->append(tmpl);
 		} catch(errorEx &err) {
-			QMessageBox::warning(mainwin, tr(XCA_TITLE),
-				tr("Bad template: %1").arg(name));
+			XCA_WARN(tr("Bad template: %1").arg(name));
 		}
 	}
 }
