@@ -1,6 +1,6 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2011 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2014 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
@@ -336,8 +336,7 @@ pki_base *db_x509::insert(pki_base *item)
 	pki_x509 *cert = (pki_x509 *)item;
 	pki_x509 *oldcert = (pki_x509 *)getByReference(cert);
 	if (oldcert) {
-		QMessageBox::information(mainwin, XCA_TITLE,
-		tr("The certificate already exists in the database as:\n'%1'\nand so it was not imported").arg(oldcert->getIntName()));
+		XCA_INFO(tr("The certificate already exists in the database as:\n'%1'\nand so it was not imported").arg(oldcert->getIntName()));
 		delete(cert);
 		return NULL;
 	}
@@ -529,16 +528,18 @@ void db_x509::newCert(NewX509 *dlg)
 	cert->setNotAfter(a);
 
 	// STEP 4 handle extensions
+
+	// apply all extensions to the subject cert in the context
+	dlg->getAllExt();
+
+	// apply extensions from CSR if requested
 	if (dlg->copyReqExtCB->isChecked() && dlg->fromReqCB->isChecked()) {
 		extList el = req->getV3ext();
 		int m = el.count();
 		for (int i=0; i<m; i++)
-			cert->addV3ext(el[i]);
+			cert->addV3ext(el[i], true);
 	}
 
-	// apply all extensions to the subject cert in the context
-	dlg->getAllExt();
-
 	const EVP_MD *hashAlgo = dlg->hashAlgo->currentHash();
 #ifdef WG_QA_SERIAL
 	if (dlg->selfQASignRB->isChecked()) {
@@ -557,10 +558,8 @@ void db_x509::newCert(NewX509 *dlg)
 	updatePKI(signcert);
 	if (cert && clientkey->isToken()) {
 		pki_scard *card = (pki_scard*)clientkey;
-		if (QMessageBox::information(mainwin, XCA_TITLE,
-			tr("Store the certificate to the key on the token '%1 (#%2)' ?").
-			arg(card->getCardLabel()).arg(card->getSerial()),
-			QMessageBox::Yes | QMessageBox::No) == QMessageBox::Yes)
+		if (XCA_YESNO(tr("Store the certificate to the key on the token '%1 (#%2)' ?").
+			arg(card->getCardLabel()).arg(card->getSerial())))
 		{
 			try {
 				cert->store_token(false);
@@ -764,14 +763,12 @@ void db_x509::store()
 		case 11: // Certificate and Key in PEM format for apache
 			pki_evp *privkey = (pki_evp *)crt->getRefKey();
 			if (!privkey || privkey->isPubKey()) {
-				QMessageBox::warning(mainwin, XCA_TITLE,
-					tr("There was no key found for the Certificate: '%1'").
+				XCA_WARN(tr("There was no key found for the Certificate: '%1'").
 					arg(crt->getIntName()));
 				return;
 			}
 			if (privkey->isToken()) {
-				QMessageBox::warning(mainwin, XCA_TITLE,
-					tr("Not possible for a token key: '%1'").
+				XCA_WARN(tr("Not possible for a token key: '%1'").
 					arg(crt->getIntName()));
                                 return;
                         }
@@ -797,13 +794,11 @@ void db_x509::writePKCS12(pki_x509 *cert, QString s, bool chain)
     try {
 		pki_evp *privkey = (pki_evp *)cert->getRefKey();
 		if (!privkey || privkey->isPubKey()) {
-			QMessageBox::warning(mainwin, XCA_TITLE,
-				tr("There was no key found for the Certificate: '%1'").arg(cert->getIntName()));
+			XCA_WARN(tr("There was no key found for the Certificate: '%1'").arg(cert->getIntName()));
 			return;
 		}
 		if (privkey->isToken()) {
-			QMessageBox::warning(mainwin, XCA_TITLE,
-				tr("Not possible for the token-key Certificate '%1'").
+			XCA_WARN(tr("Not possible for the token-key Certificate '%1'").
 				arg(cert->getIntName()));
 			return;
 		}
@@ -870,8 +865,7 @@ void ::signP7()
 	if (!cert) return;
 	pki_key *privkey = cert->getRefKey();
 	if (!privkey || privkey->isPubKey()) {
-		QMessageBox::warning(this,tr(XCA_TITLE),
-				tr("There was no key found for the Certificate: ") +
+		XCA_WARN(tr("There was no key found for the Certificate: ") +
 			cert->getIntName());
 		return;
 	}
@@ -910,8 +904,7 @@ void CertView::encryptP7()
 	if (!cert) return;
 	pki_key *privkey = cert->getRefKey();
 	if (!privkey || privkey->isPubKey()) {
-		QMessageBox::warning(this,tr(XCA_TITLE),
-			tr("There was no key found for the Certificate: ") +
+		XCA_WARN(tr("There was no key found for the Certificate: ") +
 			cert->getIntName()) ;
 		return;
 	}
