@@ -1,6 +1,6 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2011 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2014 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
@@ -40,8 +40,7 @@ pki_base *db_x509req::insert(pki_base *item)
 	req = (pki_x509req *)item;
 	oldreq = (pki_x509req *)getByReference(req);
 	if (oldreq) {
-		QMessageBox::information(mainwin, XCA_TITLE,
-		tr("The certificate signing request already exists in the database as\n'%1'\nand thus was not stored").arg(oldreq->getIntName()));
+		XCA_INFO(tr("The certificate signing request already exists in the database as\n'%1'\nand thus was not stored").arg(oldreq->getIntName()));
 		delete(req);
 		return NULL;
 	}
