@@ -1,6 +1,6 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2011 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2014 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
@@ -11,34 +11,24 @@
 #include <QtCore/QDir>
 #include "widgets/MainWindow.h"
 #include "lib/func.h"
+#include "lib/main.h"
 #ifdef WIN32
 #include <windows.h>
 #endif
 
-class XCA_application : public QApplication
+void XCA_application::setMainwin(MainWindow *m)
 {
-	MainWindow *mainw;
-	QTranslator qtTr;
-	QTranslator xcaTr;
-
-public:
-	XCA_application(int &argc, char *argv[]);
-	void setMainwin(MainWindow *m)
-	{
-		mainw = m;
-	}
-protected:
-	bool event(QEvent *ev);
-};
+	mainw = m;
+	connect(this, SIGNAL(openFiles(QStringList &)),
+		m, SLOT(openURLs(QStringList &)));
+}
 
 XCA_application::XCA_application(int &argc, char *argv[])
 	:QApplication(argc, argv)
 {
-	QString locale;
+	QLocale sys = QLocale::system();
 	QStringList dirs;
 
-	locale = QLocale::system().name();
-
 	dirs
 #ifdef XCA_DEFAULT_QT_TRANSLATE
 		<< XCA_DEFAULT_QT_TRANSLATE
@@ -52,11 +42,11 @@ XCA_application::XCA_application(int &argc, char *argv[])
 		;
 
 	foreach(QString dir, dirs) {
-		if (qtTr.load(QString("qt_%1").arg(locale), dir)) {
+		if (qtTr.load(sys, "qt", dir)) {
 			break;
 		}
 	}
-	xcaTr.load(QString("xca_%1").arg(locale), getPrefix());
+	xcaTr.load(sys, "xca", getPrefix());
 
 	installTranslator(&qtTr);
 	installTranslator(&xcaTr);
@@ -71,10 +61,9 @@ XCA_application::XCA_application(int &argc, char *argv[])
 bool XCA_application::event(QEvent *ev)
 {
 	if (ev->type() == QEvent::FileOpen) {
-		QString file = static_cast<QFileOpenEvent *>(ev)->file();
-		if (mainw)
-			mainw->importAnything(file);
-
+		QStringList l;
+		l << static_cast<QFileOpenEvent *>(ev)->file();
+		emit openFiles(l);
 		return true;
 	}
 	return QApplication::event(ev);
@@ -91,6 +80,7 @@ int main( int argc, char *argv[] )
 		a.setMainwin(mw);
 		mw->read_cmdline();
 		if (mw->exitApp == 0) {
+			mw->load_history();
 			if (mw->open_default_db() != 2) {
 				mw->show();
 				ret = a.exec();
