@@ -1,6 +1,6 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2011 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2013 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
@@ -176,12 +176,21 @@ QList<int> pki_evp::possibleHashNids()
 
 	switch (EVP_PKEY_type(key->type)) {
 		case EVP_PKEY_RSA:
-			nids << NID_md5 << NID_sha1 << NID_sha256 << NID_sha384 <<
-				NID_sha512 << NID_ripemd160;
+			nids << NID_md5 << NID_sha1 << NID_sha256 <<
+				NID_sha384 << NID_sha512 << NID_ripemd160;
 			break;
 		case EVP_PKEY_DSA:
+			nids << NID_sha1;
+#if OPENSSL_VERSION_NUMBER >= 0x10000000L
+			nids << NID_sha256;
+#endif
+			break;
 		case EVP_PKEY_EC:
 			nids << NID_sha1;
+#if OPENSSL_VERSION_NUMBER >= 0x10000000L
+			nids << NID_sha256 << NID_sha384 << NID_sha512;
+#endif
+			break;
 	}
 	return nids;
 };
