@@ -1,6 +1,6 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2012 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2014 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
@@ -279,8 +279,7 @@ void pki_x509::store_token(bool alwaysSelect)
 
 	QList<CK_OBJECT_HANDLE> objs = p11.objectList(p11_atts);
 	if (objs.count() != 0) {
-		QMessageBox::warning(NULL, XCA_TITLE,
-		    tr("This certificate is already on the security token"));
+		XCA_WARN(tr("This certificate is already on the security token"));
 		return;
 	}
 
@@ -288,6 +287,8 @@ void pki_x509::store_token(bool alwaysSelect)
 		pk11_attr_bool(CKA_TOKEN, true) <<
 		pk11_attr_bool(CKA_PRIVATE, false) <<
 		pk11_attr_data(CKA_SUBJECT, getSubject().i2d()) <<
+		pk11_attr_data(CKA_ISSUER, getIssuer().i2d()) <<
+		pk11_attr_data(CKA_SERIAL_NUMBER, getSerial().i2d()) <<
 		pk11_attr_data(CKA_LABEL, desc.toUtf8()) <<
 		(card ? card->getIdAttr() : p11.findUniqueID(CKO_CERTIFICATE));
 
@@ -340,10 +341,8 @@ void pki_x509::deleteFromToken(slotid slot)
 		return;
 
 	tkInfo ti = p11.tokenInfo();
-	if (QMessageBox::question(NULL, XCA_TITLE,
-		tr("Delete the certificate '%1' from the token '%2 (#%3)'?").
-		arg(getIntName()).arg(ti.label()).arg(ti.serial()),
-		QMessageBox::Yes | QMessageBox::No) != QMessageBox::Yes)
+	if (!XCA_YESNO(tr("Delete the certificate '%1' from the token '%2 (#%3)'?").
+		arg(getIntName()).arg(ti.label()).arg(ti.serial())))
 	{
 		return;
 	}
@@ -429,13 +428,17 @@ void pki_x509::setIssuer(const x509name &n)
 	cert->cert_info->issuer = n.get();
 }
 
-void pki_x509::addV3ext(const x509v3ext &e)
+bool pki_x509::addV3ext(const x509v3ext &e, bool skip_existing)
 {
-	if (!e.isValid()) return;
+	if (!e.isValid())
+		return false;
+	if (skip_existing && X509_get_ext_by_NID(cert, e.nid(), -1) != -1)
+		return false;
 	X509_EXTENSION *ext = e.get();
 	X509_add_ext(cert, ext, -1);
 	X509_EXTENSION_free(ext);
 	pki_openssl_error();
+	return true;
 }
 
 void pki_x509::delSigner(pki_base *s)
