@@ -8,9 +8,9 @@ LIBTOOL_DIR="libtool-2.2.6b"
 LIBTOOL_GZ="${LIBTOOL_DIR}".tar.gz
 LIBTOOL_DL="http://ftp.gnu.org/gnu/libtool/${LIBTOOL_GZ}"
 
-OPENSSL_DIR="openssl-1.0.1c"
+OPENSSL_DIR="openssl-1.0.1j"
 OPENSSL_GZ="${OPENSSL_DIR}".tar.gz
-OPENSSL_DL="http://openssl.org/source/${OPENSSL_GZ}"
+OPENSSL_DL="http://www.openssl.org/source/${OPENSSL_GZ}"
 OPENSSL_PATCH="$XCA_DIR/misc/openssl-1.0.0-mingw32-cross.patch"
 
 unpack() {
