@@ -1,6 +1,6 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2007 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2012 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
@@ -11,9 +11,9 @@
 #include "lib/pki_crl.h"
 #include "widgets/distname.h"
 #include "widgets/clicklabel.h"
-#include <qlabel.h>
-#include <qtextedit.h>
-#include <qlineedit.h>
+#include <QtGui/QLabel>
+#include <QtGui/QTextEdit>
+#include <QtGui/QLineEdit>
 
 CrlDetail::CrlDetail(MainWindow *mainwin)
 	:QDialog(mainwin)
@@ -26,7 +26,8 @@ CrlDetail::CrlDetail(MainWindow *mainwin)
 	certList->setColumnCount(3);
 
 	QStringList sl;
-	sl << tr("Name") << tr("Serial") << tr("Revocation");
+	sl << tr("Name") << tr("Serial") << tr("Revocation") << tr("Reason") <<
+		tr("Invalidation");
 	certList->setHeaderLabels(sl);
 
 	image->setPixmap(*MainWindow::revImg);
@@ -66,16 +67,20 @@ void CrlDetail::setCrl(pki_crl *crl)
 
 	descr->setText(crl->getIntName());
 	lUpdate->setText(crl->getLastUpdate().toPretty());
+	lUpdate->setToolTip(crl->getLastUpdate().toPrettyGMT());
 	nUpdate->setText(crl->getNextUpdate().toPretty());
+	nUpdate->setToolTip(crl->getNextUpdate().toPrettyGMT());
 	version->setText((++crl->getVersion()).toHex());
 
-	issuer->setX509name(crl->getIssuerName());
+	issuer->setX509name(crl->getSubject());
 
 	numc = crl->numRev();
 	for (i=0; i<numc; i++) {
 		QTreeWidgetItem *current;
+		a1time a;
 		revit = crl->getRev(i);
 		rev = mw->certs->getByIssSerial(iss, revit.getSerial());
+		certList->setColumnCount(5);
 		current = new QTreeWidgetItem(certList);
 		if (rev != NULL) {
 			current->setText(0, rev->getIntName() );
@@ -85,6 +90,13 @@ void CrlDetail::setCrl(pki_crl *crl)
 		current->setIcon(0, *pki_x509::icon[2]);
 		current->setText(1, revit.getSerial().toHex()) ;
 		current->setText(2, revit.getDate().toSortable());
+		current->setText(3, revit.getReason());
+		a = revit.getInvalDate();
+		if (!a.isUndefined())
+			current->setText(4, a.toSortable());
 	}
+	for (i=0; i<5; i++)
+		certList->resizeColumnToContents(i);
+	certList->setSortingEnabled(true);
 	v3extensions->document()->setHtml(crl->printV3ext());
 }
