@@ -1,6 +1,6 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2012 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2014 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
@@ -16,6 +16,7 @@
 #include "lib/db_base.h"
 #include "lib/func.h"
 #include "widgets/ImportMulti.h"
+#include "widgets/NewKey.h"
 
 int MainWindow::init_database()
 {
@@ -145,6 +146,13 @@ int MainWindow::init_database()
 				free(p);
 			}
 		}
+		mydb.first();
+		if (!mydb.find(setting, "defaultkey")) {
+			if ((p = (char *)mydb.load(NULL))) {
+				NewKey::setDefault((QString(p)));
+				free(p);
+			}
+		}
 		ASN1_STRING_set_default_mask_asc((char*)CCHAR(string_opt));
 		mydb.first();
 		if (!mydb.find(setting, "mw_geometry")) {
@@ -171,8 +179,7 @@ int MainWindow::init_database()
 	setWindowTitle(tr(XCA_TITLE));
 	setItemEnabled(true);
 	if (pki_evp::passwd.isNull())
-		QMessageBox::information(this, XCA_TITLE,
-			tr("Using or exporting private keys will not be possible without providing the correct password"));
+		XCA_INFO(tr("Using or exporting private keys will not be possible without providing the correct password"));
 
 	dbindex->setText(tr("Database") + ":" + dbfile);
 	load_engine();
@@ -243,8 +250,7 @@ void MainWindow::undelete()
 	if (dlgi->entries() > 0) {
 		dlgi->execute(1);
 	} else {
-		QMessageBox::information(this, XCA_TITLE,
-			tr("No deleted items found"));
+		XCA_INFO(tr("No deleted items found"));
 	}
 	delete dlgi;
 }
@@ -265,6 +271,7 @@ int MainWindow::open_default_db()
 	dbfile = filename2QString(buff).trimmed();
 	if (QFile::exists(dbfile))
 		return init_database();
+	dbfile = QString();
 	return 0;
 }
 
@@ -338,10 +345,69 @@ void MainWindow::close_database()
 	catch (errorEx &err) {
 		MainWindow::Error(err);
 	}
+	update_history(dbfile);
 	pkcs11::remove_libs();
 	enableTokenMenu(pkcs11::loaded());
 }
 
+void MainWindow::load_history()
+{
+	QFile file;
+	QString name = getUserSettingsDir() + QDir::separator() + "dbhistory";
+
+	file.setFileName(name);
+	if (!file.open(QIODevice::ReadOnly))
+		return;
+
+	history.clear();
+	while (!file.atEnd()) {
+		QString name;
+		char buf[1024];
+		ssize_t size = file.readLine(buf, sizeof buf);
+		if (size <= 0)
+			break;
+		name = filename2QString(buf);
+		name = name.trimmed();
+		if (name.size() == 0)
+			continue;
+		if (history.indexOf(name) == -1)
+			history << name;
+	}
+	file.close();
+	update_history_menu();
+}
+
+void MainWindow::update_history(QString fname)
+{
+	QFile file;
+	int pos;
+	QString name;
+
+	pos = history.indexOf(fname);
+	if (pos == 0)
+		return; /* no changes */
+
+	if (pos > 0)
+		history.removeAt(pos);
+	history.prepend(fname);
+	while (history.size() > 10)
+		history.removeLast();
+
+	name = getUserSettingsDir() + QDir::separator() + "dbhistory";
+	file.setFileName(name);
+	if (!file.open(QIODevice::ReadWrite))
+		return;
+
+	for (pos = 0; pos < history.size(); pos++) {
+		QByteArray ba = filename2bytearray(history[pos]);
+		ba.append('\n');
+		if (file.write(ba) <= 0)
+			break;
+	}
+	file.close();
+	update_history_menu();
+}
+
 /* Asymetric Key buttons */
 void MainWindow::on_BNnewKey_clicked(void)
 {
