@@ -1,6 +1,6 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2012 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2014 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
@@ -70,7 +70,7 @@ void MainWindow::about()
 
 	cont = QString(
 	"<p><h3><center><u>XCA</u></center></h3>"
-	"<p>Copyright 2001 - 2012 by Christian Hohnst&auml;dt\n"
+	"<p>Copyright 2001 - 2014 by Christian Hohnst&auml;dt\n"
 	"<p>Version : <b>" VER "</b>"
 	"<p>%1"
 	"<hr><table border=0>"
@@ -90,11 +90,13 @@ void MainWindow::about()
 	"<tr><td><b>Thorsten Weiss</b></td><td><u>&lt;weiss2@gmx.de&gt;</u></td></tr>"
 	"<tr><td><b>Oobj</b></td><td><u>&lt;www.oobj.com.br&gt;</u></td></tr>"
 	"<tr><td><b>Frank Isemann</b></td><td><u>&lt;isemannf@firflabs.net&gt;</u></td></tr>"
+	"<tr><td><b>Helmut Strobl</b></td><td><u>&lt;helmut.strobl@t-online.de&gt;</u></td></tr>"
 	"</table><hr><center><u><b>Translations</b></u></center>"
 	"<p><table>"
 	"<tr><th>German</th><td>Christian Hohnst&auml;dt</td></tr>"
 	"<tr><th>Russian</th><td>Pavel Belly &lt;pavel.belly@gmail.com&gt;</td></tr>"
 	"<tr><th>French</th><td>Patrick Monnerat &lt;Patrick.Monnerat@datasphere.ch&gt;</td></tr>"
+	"<tr><th>Croatian</th><td>Nevenko Bartolincic &lt;nevenko.bartolincic@gmail.com&gt;</td></tr>"
 	"</table>").
 		arg(version);
 
