@@ -1,6 +1,6 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2012 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2014 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
@@ -26,11 +26,16 @@ void MainWindow::init_menu()
 {
 	QMenu *file, *help, *import, *token;
 
+	historyMenu = new tipMenu(tr("Recent DataBases") + " ...", this);
+	connect(historyMenu, SIGNAL(triggered(QAction*)),
+                this, SLOT(open_database(QAction*)));
+
 	file = menuBar()->addMenu(tr("&File"));
 	file->addAction(tr("&New DataBase"), this, SLOT(new_database()),
 		QKeySequence::New);
 	file->addAction(tr("&Open DataBase"), this, SLOT(load_database()),
 		QKeySequence::Open);
+	file->addMenu(historyMenu);
 	file->addAction(tr("Generate DH parameter"), this,
 				 SLOT(generateDHparam()));
 	acList += file->addAction(tr("Set as default DataBase"), this,
@@ -101,6 +106,26 @@ int MainWindow::changeDB(QString fname)
 	return init_database();
 }
 
+void MainWindow::update_history_menu()
+{
+	historyMenu->clear();
+	for (int i = 0; i < history.size(); i++) {
+		QAction *a;
+		QString txt = history[i];
+		txt = txt.remove(0, txt.lastIndexOf(QDir::separator()) +1);
+		if (txt.size() > 20)
+			txt = QString("...") + txt.mid(txt.size() - 20);
+		a = historyMenu->addAction(QString("%1 %2").arg(i).arg(txt));
+		a->setData(QVariant(history[i]));
+		a->setToolTip(history[i]);
+	}
+}
+
+void MainWindow::open_database(QAction* a)
+{
+	changeDB(a->data().toString());
+}
+
 void MainWindow::new_database()
 {
 	load_db l;
@@ -144,10 +169,12 @@ void MainWindow::import_dbdump()
 	try {
 		read_dump(CCHAR(file), dbl, buf, sizeof(buf));
 		if (pki_evp::md5passwd(pass) != buf) {
-			int ret = QMessageBox::warning(this, tr(XCA_TITLE),
-				tr("Password verification error. Ignore keys ?"),
-				tr("Import anyway"), tr("Cancel"));
-			if (ret)
+			xcaWarning msg(this, tr("Password verification error. Ignore keys ?"));
+			msg.addButton(QMessageBox::Cancel);
+			msg.addButton(QMessageBox::Ok)->setText(
+					tr("Import anyway"));
+
+			if (msg.exec() == QMessageBox::Cancel)
 				return;
 		}
 		pki_evp::oldpasswd = pass;
