@@ -1,6 +1,6 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2012 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2014 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
@@ -63,6 +63,7 @@ static const int x962_curve_nids[] = {
 	NID_X9_62_prime239v2,
 	NID_X9_62_prime239v3,
 	NID_X9_62_prime256v1,
+
 	NID_X9_62_c2pnb163v1,
 	NID_X9_62_c2pnb163v2,
 	NID_X9_62_c2pnb163v3,
@@ -82,19 +83,67 @@ static const int x962_curve_nids[] = {
 };
 
 static const int other_curve_nids[] = {
+	NID_sect113r1,
+	NID_sect113r2,
+	NID_sect131r1,
+	NID_sect131r2,
 	NID_sect163k1,
+	NID_sect163r1,
 	NID_sect163r2,
+	NID_sect193r1,
+	NID_sect193r2,
 	NID_sect233k1,
 	NID_sect233r1,
+	NID_sect239k1,
 	NID_sect283k1,
 	NID_sect283r1,
 	NID_sect409k1,
 	NID_sect409r1,
 	NID_sect571k1,
 	NID_sect571r1,
+
+	NID_secp112r1,
+	NID_secp112r2,
+	NID_secp128r1,
+	NID_secp128r2,
+	NID_secp160k1,
+	NID_secp160r1,
+	NID_secp160r2,
+	NID_secp192k1,
+	NID_secp224k1,
 	NID_secp224r1,
+	NID_secp256k1,
 	NID_secp384r1,
-	NID_secp521r1
+	NID_secp521r1,
+
+	NID_wap_wsg_idm_ecid_wtls1,
+	NID_wap_wsg_idm_ecid_wtls3,
+	NID_wap_wsg_idm_ecid_wtls4,
+	NID_wap_wsg_idm_ecid_wtls5,
+	NID_wap_wsg_idm_ecid_wtls6,
+	NID_wap_wsg_idm_ecid_wtls7,
+	NID_wap_wsg_idm_ecid_wtls8,
+	NID_wap_wsg_idm_ecid_wtls9,
+	NID_wap_wsg_idm_ecid_wtls10,
+	NID_wap_wsg_idm_ecid_wtls11,
+	NID_wap_wsg_idm_ecid_wtls12,
+
+#if OPENSSL_VERSION_NUMBER >= 0x10002001L
+	NID_brainpoolP160r1,
+	NID_brainpoolP160t1,
+	NID_brainpoolP192r1,
+	NID_brainpoolP192t1,
+	NID_brainpoolP224r1,
+	NID_brainpoolP224t1,
+	NID_brainpoolP256r1,
+	NID_brainpoolP256t1,
+	NID_brainpoolP320r1,
+	NID_brainpoolP320t1,
+	NID_brainpoolP384r1,
+	NID_brainpoolP384t1,
+	NID_brainpoolP512r1,
+	NID_brainpoolP512t1
+#endif
 };
 
 static void init_curves()
@@ -198,6 +247,8 @@ MainWindow::MainWindow(QWidget *parent )
 	eku_nid = read_nidlist("eku.txt");
 	dn_nid = read_nidlist("dn.txt");
 	aia_nid = read_nidlist("aia.txt");
+	connect(this, SIGNAL(newURLs(QStringList &)),
+		this, SLOT(openURLs(QStringList &)));
 	setAcceptDrops(true);
 }
 
@@ -205,11 +256,23 @@ void MainWindow::dropEvent(QDropEvent *event)
 {
 	QList<QUrl> urls = event->mimeData()->urls();
 	QUrl u;
-	ImportMulti *dlgi = new ImportMulti(this);
-	QStringList failed;
+	QStringList files;
 
 	foreach(u, urls) {
 		QString s = u.toLocalFile();
+		files << s;
+	}
+	emit newURLs(files);
+	event->acceptProposedAction();
+}
+
+void MainWindow::openURLs(QStringList &files)
+{
+	QStringList failed;
+	QString s;
+	ImportMulti *dlgi = new ImportMulti(this);
+
+	foreach(s, files) {
 	        pki_multi *pki = probeAnything(s);
 		if (pki && !pki->count())
 			failed << s;
@@ -217,7 +280,6 @@ void MainWindow::dropEvent(QDropEvent *event)
 	}
 	dlgi->execute(1, failed);
 	delete dlgi;
-	event->acceptProposedAction();
 }
 
 void MainWindow::dragEnterEvent(QDragEnterEvent *event)
@@ -569,9 +631,7 @@ void MainWindow::manageToken()
 		}
 		if (dlgi->entries() == 0) {
 			tkInfo ti = p11.tokenInfo();
-			QMessageBox::information(this, XCA_TITLE,
-				tr("The token '%1' did not contain any keys or certificates").
-                                arg(ti.label()));
+			XCA_INFO(tr("The token '%1' did not contain any keys or certificates").arg(ti.label()));
 		} else {
 			dlgi->execute(true);
 		}
@@ -747,7 +807,7 @@ int MainWindow::initPass()
 				!= pki_evp::passHash)
 		{
 			if (ret)
-				QMessageBox::warning(this, XCA_TITLE,
+				XCA_WARN(
 				tr("Password verify error, please try again"));
 			p.setTitle(tr("Password"));
 			p.setDescription(tr("Please enter the password for unlocking the database:\n%1").arg(compressFilename(dbfile)));
@@ -785,9 +845,9 @@ void MainWindow::Error(errorEx &err)
 	if (err.isEmpty())
 		 return;
 	QString msg =  tr("The following error occured:") + "\n" + err.getString();
-	QMessageBox box(QMessageBox::Warning, XCA_TITLE,
-		msg, QMessageBox::Ok, NULL);
+	xcaWarning box(NULL, msg);
 	box.addButton(QMessageBox::Apply)->setText(tr("Copy to Clipboard"));
+	box.addButton(QMessageBox::Ok);
 	if (box.exec() == QMessageBox::Apply) {
 		QClipboard *cb = QApplication::clipboard();
 		if (cb->supportsSelection())
@@ -809,6 +869,12 @@ void MainWindow::setPath(QString str)
 	mydb.set((const unsigned char *)CCHAR(str), str.length()+1, 1, setting, "workingdir");
 }
 
+void MainWindow::setDefaultKey(QString str)
+{
+	db mydb(dbfile);
+	mydb.set((const unsigned char *)CCHAR(str), str.length()+1, 1, setting, "defaultkey");
+}
+
 void MainWindow::connNewX509(NewX509 *nx)
 {
 	connect( nx, SIGNAL(genKey(QString)), keys, SLOT(newItem(QString)) );
