@@ -1,6 +1,6 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2012 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2014 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
@@ -22,12 +22,45 @@
 #include <QtGui/QFileDialog>
 #include <QtGui/QMenuBar>
 #include <QtCore/QList>
+#include <QtGui/QMessageBox>
+#include <QtGui/QMenu>
+#include <QtGui/QToolTip>
 
 #define DBFILE "xca.xdb"
 
 class db_x509;
 class pki_multi;
 
+class xcaWarning: public QMessageBox
+{
+	public:
+		xcaWarning(QWidget *w, QString txt)
+			: QMessageBox(QMessageBox::Warning,
+				 XCA_TITLE, txt, QMessageBox::NoButton, w)
+		{
+			setTextFormat(Qt::PlainText);
+		}
+};
+
+class tipMenu : public QMenu
+{
+	Q_OBJECT
+
+    public:
+	tipMenu(QString n, QWidget *w) : QMenu(n, w) {}
+	bool event (QEvent * e)
+	{
+		const QHelpEvent *helpEvent = static_cast <QHelpEvent *>(e);
+		if (helpEvent->type() == QEvent::ToolTip && activeAction()) {
+			QToolTip::showText(helpEvent->globalPos(),
+				activeAction()->toolTip());
+		} else {
+			QToolTip::hideText();
+		}
+		return QMenu::event(e);
+	}
+};
+
 class MainWindow: public QMainWindow, public Ui::MainWindow
 {
 	Q_OBJECT
@@ -39,6 +72,9 @@ class MainWindow: public QMainWindow, public Ui::MainWindow
 		QList<QWidget*> wdList;
 		QList<QWidget*> scardList;
 		QList<QAction*> acList;
+		QStringList history;
+		tipMenu *historyMenu;
+		void update_history_menu();
 
 	protected:
 		void init_images();
@@ -88,6 +124,9 @@ class MainWindow: public QMainWindow, public Ui::MainWindow
 		void dropEvent(QDropEvent *event);
 		void dragEnterEvent(QDragEnterEvent *event);
 		int open_default_db();
+		void setDefaultKey(QString def);
+		void load_history();
+		void update_history(QString file);
 
 	public slots:
 		int init_database();
@@ -106,6 +145,10 @@ class MainWindow: public QMainWindow, public Ui::MainWindow
 		bool pastePem(QString text);
 		void pastePem();
 		void changeDbPass();
+		void openURLs(QStringList &files);
+
+	signals:
+		void newURLs(QStringList &);
 
 	private slots:
 		void setOptions();
@@ -115,6 +158,7 @@ class MainWindow: public QMainWindow, public Ui::MainWindow
 		void changeSoPin();
 		void initPin();
 		void generateDHparam();
+		void open_database(QAction* a);
 
 		void on_keyView_doubleClicked(const QModelIndex &m);
 		void on_reqView_doubleClicked(const QModelIndex &m);
