@@ -1,6 +1,6 @@
 /* vi: set sw=4 ts=4:
  *
- * Copyright (C) 2001 - 2012 Christian Hohnstaedt.
+ * Copyright (C) 2001 - 2014 Christian Hohnstaedt.
  *
  * All rights reserved.
  */
@@ -648,7 +648,7 @@ x509name NewX509::getX509name(int _throw)
 			if (_throw)
 				throw err;
 			else
-				QMessageBox::warning(this, XCA_TITLE, err.getString());
+				XCA_WARN(err.getString());
 		}
 	}
 	return x;
@@ -725,6 +725,13 @@ void NewX509::editV3ext(QLineEdit *le, QString types, int n)
 
 	dlg = new v3ext(this);
 	setupTmpCtx();
+	if (n == NID_info_access) {
+		int nid, idx = aiaOid->currentIndex();
+		if (idx >= 0 && idx < aia_nid.size()) {
+			nid = aia_nid[idx];
+			dlg->setPrefix(QString(OBJ_nid2sn(nid)) + ";");
+		}
+	}
 	dlg->addInfo(le, types.split(',' ), n, &ext_ctx);
 	dlg->exec();
 	delete(dlg);
@@ -817,17 +824,10 @@ int NewX509::validateExtensions(QString nconf, QString &result)
 {
 	int ret = 0;
 	QStringList errors;
-	extList el;
+	extList el, req_el;
 	ign_openssl_error();
 	setupTmpCtx();
-	if (fromReqCB->isChecked() && copyReqExtCB->isChecked()) {
-		el = getSelectedReq()->getV3ext();
-	}
-	if (el.size() > 0) {
-		result = "<h2><center>";
-		result += tr("From PKCS#10 request") +"</center></h2><p>\n";
-		result += el.getHtml("<br>");
-	}
+	(void)nconf;
 	try {
 		el = getGuiExt();
 		el += getNetscapeExt();
@@ -837,8 +837,6 @@ int NewX509::validateExtensions(QString nconf, QString &result)
 		el.clear();
 	}
 	if (el.size() > 0) {
-		if (!result.isEmpty())
-			result += "\n<hr>\n";
 		result += "<h2><center>";
 		result += tr("Other Tabs") + "</center></h2><p>\n";
 		result += el.getHtml("<br>");
@@ -865,6 +863,21 @@ int NewX509::validateExtensions(QString nconf, QString &result)
 		result += "</li></ul>";
 		ret = 1;
 	}
+	el.clear();
+	if (fromReqCB->isChecked() && copyReqExtCB->isChecked()) {
+		req_el = getSelectedReq()->getV3ext();
+                for (int i=0; i<req_el.count(); i++) {
+			if (ctx_cert && ctx_cert->addV3ext(req_el[i], true))
+				el += req_el[i];
+		}
+	}
+	if (el.size() > 0) {
+		if (!result.isEmpty())
+			result += "\n<hr>\n";
+		result += "<h2><center>";
+		result += tr("From PKCS#10 request") +"</center></h2><p>\n";
+		result += el.getHtml("<br>");
+	}
 	el = getExtDuplicates();
 	if (el.size() > 0) {
 		QString errtxt;
@@ -946,8 +959,7 @@ void NewX509::accept()
 		xn = getX509name(1);
 	} catch (errorEx &err) {
 		gotoTab(1);
-		QMessageBox msg(QMessageBox::Warning, XCA_TITLE, err.getString(),
-			QMessageBox::NoButton, this);
+		xcaWarning msg(this, err.getString());
 		msg.addButton(QMessageBox::Ok);
 		msg.addButton(QMessageBox::Close)->setText(tr("Abort rollout"));
 		if (msg.exec() == QMessageBox::Close) {
@@ -960,8 +972,7 @@ void NewX509::accept()
 		gotoTab(1);
 		lenErr = tr("The following length restrictions of RFC3280 are violated:") +
 			"\n" + lenErr;
-		QMessageBox msg(QMessageBox::Warning, XCA_TITLE,
-					lenErr, QMessageBox::NoButton, this);
+		xcaWarning msg(this, lenErr);
 		msg.addButton(QMessageBox::Ok)->setText(tr("Edit subject"));
 		msg.addButton(QMessageBox::Close)->setText(tr("Abort rollout"));
 		msg.addButton(QMessageBox::Apply)->setText(tr("Continue rollout"));
@@ -979,9 +990,8 @@ void NewX509::accept()
 	}
 	if (fromReqCB->isChecked() && !getSelectedReq()->verify()) {
 		gotoTab(0);
-		QMessageBox msg(QMessageBox::Warning, XCA_TITLE,
-			tr("The verification of the Certificate request failed.\nThe rollout should be aborted."),
-			QMessageBox::NoButton, this);
+		xcaWarning msg(this,
+			tr("The verification of the Certificate request failed.\nThe rollout should be aborted."));
 		msg.addButton(QMessageBox::Ok)->setText(tr("Continue anyway"));
 		msg.addButton(QMessageBox::Close)->setText(tr("Abort rollout"));
 		if (msg.exec() == QMessageBox::Close) {
@@ -991,8 +1001,8 @@ void NewX509::accept()
 	if (description->text().isEmpty() && !fromReqCB->isChecked()) {
 		if (commonName->text().isEmpty()) {
 			gotoTab(1);
-			QMessageBox msg(QMessageBox::Warning, XCA_TITLE,
-				tr("The internal name and the common name are empty.\nPlease set at least the internal name."), QMessageBox::NoButton, this);
+			xcaWarning msg(this,
+				tr("The internal name and the common name are empty.\nPlease set at least the internal name."));
 			msg.addButton(QMessageBox::Ok)->setText(tr("Edit name"));
 			msg.addButton(QMessageBox::Close)->setText(tr("Abort rollout"));
 			if (msg.exec() == QMessageBox::Close) {
@@ -1007,9 +1017,8 @@ void NewX509::accept()
 				!fromReqCB->isChecked())
 	{
 		gotoTab(1);
-		QMessageBox msg(QMessageBox::Warning, XCA_TITLE,
-			tr("There is no Key selected for signing."),
-			QMessageBox::NoButton, this);
+		xcaWarning msg(this,
+			tr("There is no Key selected for signing."));
 		msg.addButton(QMessageBox::Ok)->setText(tr("Select key"));
 		msg.addButton(QMessageBox::Close)->setText(tr("Abort rollout"));
 		if (msg.exec() == QMessageBox::Close) {
@@ -1023,8 +1032,7 @@ void NewX509::accept()
 	if (!unsetDN.isEmpty()) {
 		gotoTab(1);
 		QString text = tr("The following distinguished name entries are empty:\n%1\nthough you have declared them as mandatory in the options menu.").arg(unsetDN);
-		QMessageBox msg(QMessageBox::Warning, XCA_TITLE,
-					text, QMessageBox::NoButton, this);
+		xcaWarning msg(this, text);
 		msg.addButton(QMessageBox::Ok)->setText(tr("Edit subject"));
 		msg.addButton(QMessageBox::Close)->setText(tr("Abort rollout"));
 		msg.addButton(QMessageBox::Apply)->setText(tr("Continue rollout"));
@@ -1040,20 +1048,24 @@ void NewX509::accept()
 				break;
 		}
 	}
+	pki_key *signkey = NULL;
 	pki_x509 *signer = NULL;
-	if (!selfSignRB->isChecked())
+	if (foreignSignRB->isChecked()) {
 		signer = getSelectedSigner();
-
-	pki_key *signkey = getSelectedKey();
-	if (signer)
-		signkey = signer->getRefKey();
-
+		if (signer)
+			signkey = signer->getRefKey();
+	} else if (fromReqCB->isChecked()) {
+		pki_x509req *req = getSelectedReq();
+		if (req)
+			signkey = req->getRefKey();
+	} else {
+		signkey = getSelectedKey();
+	}
 	if ((!signkey || signkey->isPubKey()) && pt != tmpl) {
 		QString txt;
 		gotoTab(signer ? 0 : 1);
-		QMessageBox msg(QMessageBox::Warning, XCA_TITLE,
-			tr("The key you selected for signing is not a private one."),
-			QMessageBox::NoButton, this);
+		xcaWarning msg(this,
+			tr("The key you selected for signing is not a private one."));
 		txt = signer ? tr("Select other signer"):tr("Select other key");
 		msg.addButton(QMessageBox::Ok)->setText(txt);
 		msg.addButton(QMessageBox::Close)->setText(tr("Abort rollout"));
@@ -1065,8 +1077,7 @@ void NewX509::accept()
 	if (signer && notBefore->getDate() < signer->getNotBefore()) {
 		gotoTab(2);
 		QString text = tr("The certificate will be earlier valid than the signer. This is probably not what you want.");
-		QMessageBox msg(QMessageBox::Warning, XCA_TITLE,
-					text, QMessageBox::NoButton, this);
+		xcaWarning msg(this, text);
 		msg.addButton(QMessageBox::Ok)->setText(tr("Edit dates"));
 		msg.addButton(QMessageBox::Close)->setText(tr("Abort rollout"));
 		msg.addButton(QMessageBox::Apply)->setText(tr("Continue rollout"));
@@ -1089,8 +1100,7 @@ void NewX509::accept()
 				!noWellDefinedExpDate->isChecked()) {
 		gotoTab(2);
 		QString text = tr("The certificate will be longer valid than the signer. This is probably not what you want.");
-		QMessageBox msg(QMessageBox::Warning, XCA_TITLE,
-					text, QMessageBox::NoButton, this);
+		xcaWarning msg(this, text);
 		msg.addButton(QMessageBox::Ok)->setText(tr("Edit dates"));
 		msg.addButton(QMessageBox::Close)->setText(tr("Abort rollout"));
 		msg.addButton(QMessageBox::Apply)->setText(tr("Continue rollout"));
@@ -1112,8 +1122,7 @@ void NewX509::accept()
 	if (notBefore->getDate() > notAfter->getDate()) {
 		gotoTab(2);
 		QString text = tr("The certificate will be out of date before it becomes valid. You most probably mixed up both dates.");
-		QMessageBox msg(QMessageBox::Warning, XCA_TITLE,
-					text, QMessageBox::NoButton, this);
+		xcaWarning msg(this, text);
 		msg.addButton(QMessageBox::Ok)->setText(tr("Edit dates"));
 		msg.addButton(QMessageBox::Close)->setText(tr("Abort rollout"));
 		msg.addButton(QMessageBox::Apply)->setText("Continue rollout");
@@ -1132,8 +1141,7 @@ void NewX509::accept()
 	if (do_validateExtensions()) {
 		gotoTab(5);
 		QString text = tr("The certificate contains invalid or duplicate extensions. Check the validation on the advanced tab.");
-		QMessageBox msg(QMessageBox::Warning, XCA_TITLE,
-					text, QMessageBox::NoButton, this);
+		xcaWarning msg(this, text);
 		msg.addButton(QMessageBox::Ok)->setText(tr("Edit extensions"));
 		msg.addButton(QMessageBox::Close)->setText(tr("Abort rollout"));
 		msg.addButton(QMessageBox::Apply)->setText(tr("Continue rollout"));
